@@ -1,6 +1,3 @@
-#include <R.h>
-#include <Rinternals.h>
-#include <R_ext/Rdynload.h>
 #include "register_routines.h"
 
 static R_CallMethodDef callMethods[] = {
